package org.expeditee.io;

import java.awt.Color;
import java.awt.Font;

import junit.framework.TestCase;

import org.expeditee.items.Item;

public class ConversionTest extends TestCase {

	public final void testGetColor() {
		assertTrue(Conversion.getColor("100 0 0", Color.white).equals(Color.red));
		assertTrue(Conversion.getColor("0 100 0", Color.white).equals(Color.green));
		assertTrue(Conversion.getColor("0 0 100", Color.white).equals(Color.blue));
		assertTrue(Conversion.getColor("100 100 100", Color.white).equals(Color.white));
		assertEquals(Color.green,Conversion.getColor("-100 0 100", Color.white));
		assertEquals(Conversion.getColor("+0 100 0", Color.black),Color.green);
		assertEquals(Color.white, Conversion.getColor("a0a0a0", Color.white));
		assertEquals(Conversion.getColor("red9", Color.white),new Color(0.9F, 0.0F, 0.0F));
		assertEquals(Conversion.getColor("BlUe15", Color.white),new Color(0.0F, 0.0F, 1.0F));
		assertEquals(Conversion.getColor("GREEN0", Color.white),new Color(0.0F, 0.0F, 0.0F));
	}

	public final void testGetKMSColorCode() {
		assertTrue(Conversion.getKMSColorCode(Color.red).equals("100 0 0"));
		assertTrue(Conversion.getKMSColorCode(Color.green).equals("0 100 0"));
		assertTrue(Conversion.getKMSColorCode(Color.blue).equals("0 0 100"));
	}

	/*public final void testAdjustIntInt() {
		fail("Not yet implemented");
	}

	public final void testAdjustPoint() {
		fail("Not yet implemented");
	}

	public final void testDeAdjust() {
		fail("Not yet implemented");
	}

	public final void testGetKMSFontCode() {
		fail("Not yet implemented");
	}

	public final void testGetFont() {
		fail("Not yet implemented");
	}*/

	public final void testGetFrameNumber() {
		assertEquals(1, Conversion.getFrameNumber("a1"));
		assertEquals(91, Conversion.getFrameNumber("a91"));
		assertEquals(1, Conversion.getFrameNumber("a1C1"));
	}

	public final void testGetFrameset() {
		assertTrue(Conversion.getFrameset("a1").equals("a"));
		assertTrue(Conversion.getFrameset("a91").equals("a"));
		assertTrue(Conversion.getFrameset("Aa1C1").equals("aa1c"));
		assertTrue(Conversion.getFrameset("Aa1C1", false).equals("Aa1C"));
		assertTrue(Conversion.getFrameset("Abc1C1", true).equals(
				Conversion.getFrameset("Abc1C1")));
	}

	public final void testGetJustification() {
		assertEquals(Item.JUSTIFICATION_CENTER, Conversion.getJustification("center"));
		assertEquals(Item.JUSTIFICATION_CENTER, Conversion.getJustification("c"));
		assertEquals(Item.JUSTIFICATION_RIGHT, Conversion.getJustification("R"));
		assertEquals(Item.JUSTIFICATION_RIGHT, Conversion.getJustification("RIGHT"));
		assertEquals(Item.JUSTIFICATION_LEFT, Conversion.getJustification("L"));
		assertEquals(Item.JUSTIFICATION_LEFT, Conversion.getJustification("lEfT"));
		assertEquals(Item.JUSTIFICATION_FULL, Conversion.getJustification("f"));
		assertEquals(Item.JUSTIFICATION_FULL, Conversion.getJustification("FuLl"));
		assertEquals(Item.JUSTIFICATION_NONE, Conversion.getJustification("NONE"));
	}

	public final void testGetKMSJustificationCode() {
		assertEquals("C", Conversion.getKMSJustificationCode(Item.JUSTIFICATION_CENTER));
		assertEquals("L", Conversion.getKMSJustificationCode(Item.JUSTIFICATION_LEFT));
		assertEquals("R", Conversion.getKMSJustificationCode(Item.JUSTIFICATION_RIGHT));
		assertEquals("F", Conversion.getKMSJustificationCode(Item.JUSTIFICATION_FULL));
		assertEquals(null, Conversion.getKMSJustificationCode(Item.JUSTIFICATION_NONE));
		assertEquals(null, Conversion.getKMSJustificationCode(Integer.MAX_VALUE));
		assertEquals(null, Conversion.getKMSJustificationCode(Integer.MIN_VALUE));
	}

	public final void testConvertClassString() {
		assertEquals("Test", Conversion.Convert(String.class, "Test"));
		assertEquals(null, Conversion.Convert(String.class, ""));
		assertEquals(Conversion.getFont("tr16"), Conversion.Convert(Font.class, "tr16"));
		assertEquals(Color.red, Conversion.Convert(Color.class, "red"));
		assertEquals(Color.red, Conversion.Convert(Color.class, "Red"));
		assertEquals(Color.red, Conversion.Convert(Color.class, "RED"));
		assertEquals(Color.red, Conversion.Convert(Color.class, " 100 "));
		assertEquals(Color.green, Conversion.Convert(Color.class, "0  100"));
		assertEquals(Color.blue, Conversion.Convert(Color.class, "0 0 100"));
	}

	public final void testConvertClassStringObject() {
		assertEquals(Color.red, Conversion.Convert(Color.class, "+100 0 -100", Color.blue));
		assertEquals(Color.black, Conversion.Convert(Color.class, "-0 0 100", Color.blue));
		//TODO add more stuff to here
	}

	public final void testConvertMethodString() {
	}

	public final void testConvertMethodStringObject() {
	}

	public final void testConvertToKMS() {
	}

}
